@@ -84,8 +84,8 @@
 
 (defun riece-handle-ctcp-version-request (prefix target string)
   (let ((buffer (if (riece-channel-p target)
-		    (riece-channel-buffer-name
-		     (riece-make-identity target riece-server-name))))
+		    (riece-channel-buffer (riece-make-identity
+					   target riece-server-name))))
 	(user (riece-prefix-nickname prefix)))
     (riece-send-string
      (format "NOTICE %s :\1VERSION %s\1\r\n" user (riece-extended-version)))
@@ -105,8 +105,8 @@
 
 (defun riece-handle-ctcp-ping-request (prefix target string)
   (let ((buffer (if (riece-channel-p target)
-		    (riece-channel-buffer-name
-		     (riece-make-identity target riece-server-name))))
+		    (riece-channel-buffer (riece-make-identity
+					   target riece-server-name))))
 	(user (riece-prefix-nickname prefix)))
     (riece-send-string
      (if string
@@ -128,8 +128,8 @@
 
 (defun riece-handle-ctcp-clientinfo-request (prefix target string)
   (let ((buffer (if (riece-channel-p target)
-		    (riece-channel-buffer-name
-		     (riece-make-identity target riece-server-name))))
+		    (riece-channel-buffer (riece-make-identity
+					   target riece-server-name))))
 	(user (riece-prefix-nickname prefix)))
     (riece-send-string
      (format "NOTICE %s :\1CLIENTINFO %s\1\r\n"
@@ -164,8 +164,8 @@
 
 (defun riece-handle-ctcp-action-request (prefix target string)
   (let ((buffer (if (riece-channel-p target)
-		    (riece-channel-buffer-name
-		     (riece-make-identity target riece-server-name))))
+		    (riece-channel-buffer (riece-make-identity
+					   target riece-server-name))))
 	(user (riece-prefix-nickname prefix)))
     (riece-insert-change buffer (concat user " " string "\n"))
     (riece-insert-change
@@ -289,8 +289,8 @@
   (riece-send-string (format "PRIVMSG %s :\1ACTION %s\1\r\n"
 			     (riece-identity-prefix channel)
 			     action))
-  (let ((buffer (riece-channel-buffer-name
-		 (riece-make-identity channel riece-server-name))))
+  (let ((buffer (riece-channel-buffer (riece-make-identity
+				       channel riece-server-name))))
     (riece-insert-change
      buffer
      (concat (riece-identity-prefix (riece-current-nickname)) " " action "\n"))
