@@ -32,8 +32,14 @@
 (require 'riece-server)
 (require 'riece-user)
 
-(defun riece-get-buffer-create (name)
-  (let ((buffer (get-buffer-create name)))
+(defun riece-get-buffer-create (name &optional init-major-mode)
+  (let ((buffer (get-buffer name)))
+    (unless (and buffer
+		 (or (null init-major-mode)
+		     (eq (with-current-buffer buffer
+			   major-mode)
+			 init-major-mode)))
+      (setq buffer (generate-new-buffer name)))
     (unless (memq buffer riece-buffer-list)
       (setq riece-buffer-list (cons buffer riece-buffer-list)))
     buffer))
@@ -59,7 +65,7 @@
   (while buffers
     (run-hooks 'riece-before-insert-functions)
     (save-excursion
-      (set-buffer (riece-get-buffer-create (car buffers)))
+      (set-buffer (car buffers))
       (let ((inhibit-read-only t)
 	    buffer-read-only
 	    (start (goto-char (point-max))))
@@ -101,7 +107,7 @@
 
 (defun riece-current-nickname ()
   "Return the current nickname."
-  (riece-with-server-buffer (riece-identity-server riece-current-channel)
+  (riece-with-server-buffer (riece-current-server-name)
     (if riece-real-nickname
 	(riece-make-identity riece-real-nickname riece-server-name))))
 
@@ -175,7 +181,7 @@
     user-at-host))
 
 (defun riece-get-users-on-server ()
-  (riece-with-server-buffer (riece-identity-server riece-current-channel)
+  (riece-with-server-buffer (riece-current-server-name)
     (let (users)
       (mapatoms
        (lambda (atom)
@@ -186,6 +192,15 @@
 	  users
 	(cons riece-real-nickname users)))))
 
+(defun riece-check-channel-commands-are-usable (&optional channel)
+   (unless riece-current-channel
+     (error (substitute-command-keys
+	     "Type \\[riece-command-join] to join a channel")))
+   (if (and channel
+	    (not (riece-channel-p (riece-identity-prefix
+				   riece-current-channel))))
+       (error "Not on a channel")))
+
 (provide 'riece-misc)
 
 ;;; riece-misc.el ends here
