@@ -271,8 +271,8 @@ puts(\"#{" address " >> 24 & 0xFF}.#{" address " >> 16 & 0xFF}.#{"
 	    (port (string-to-number (match-string 3 message)))
 	    (size (string-to-number (match-string 4 message)))
 	    (buffer (if (riece-channel-p target)
-			(riece-channel-buffer-name
-			 (riece-make-identity target riece-server-name))))
+			(riece-channel-buffer (riece-make-identity
+					       target riece-server-name))))
 	    (user (riece-prefix-nickname prefix)))
 	(setq riece-rdcc-requests
 	      (cons (list user file address port size)
